"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var metadata_1 = require("../../metadata");
var validation_1 = require("../ruleset/validation");
var Ajv = require('ajv');
var Controller = /** @class */ (function () {
    // ########################################
    function Controller(consoleArguments, currentRootPath) {
        this.consoleArguments = consoleArguments;
        this.currentRootPath = currentRootPath;
        // ########################################
        this.metadata = metadata_1.METADATA;
    }
    // ########################################
    Controller.prototype.process = function () {
        var command = null;
        if (this.consoleArguments.includes('--help')) {
            this.printHelpCommands();
            return;
        }
        for (var i = 0; i < this.consoleArguments.length; i++) {
            if (this.metadata.commands[this.consoleArguments[i]]) {
                command = this.consoleArguments[i];
                break;
            }
        }
        if (!command) {
            this.printHelpCommands();
            throw new Error('Command not found.');
        }
        var commandSettings = this.metadata['commands'][command];
        var commandHandler = new commandSettings['handler'](this.consoleArguments, commandSettings, new validation_1.Validation(this.currentRootPath, this.metadata['allowed_protocol_versions'], new Ajv()));
        commandHandler.process();
    };
    // ########################################
    Controller.prototype.printHelpCommands = function () {
        var output = "Help \\n";
        for (var commandData in this.metadata.commands) {
            if (this.metadata.commands.hasOwnProperty(commandData)) {
                if (this.metadata.commands[commandData]['help']) {
                    output += this.metadata.commands[commandData]['help'] + '\n';
                }
            }
        }
        console.log(output);
    };
    return Controller;
}());
exports.Controller = Controller;
