"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs = __importStar(require("fs"));
var PATH = __importStar(require("path"));
var child_process_1 = require("child_process");
var Command = /** @class */ (function () {
    function Command(consoleArguments, commandSettings, rulesetValidation) {
        this.consoleArguments = consoleArguments;
        this.commandSettings = commandSettings;
        this.rulesetValidation = rulesetValidation;
        // ########################################
        this.projectRootPath = '';
        // ########################################
        this.projectsBinPath = {
            html: "/node_modules/.bin/validation-html-engine",
            scss: '/node_modules/.bin/validation-scss-engine',
            ts_style: '/node_modules/.bin/validation-ts-style-engine',
            ts_syntax: "/node_modules/.bin/validation-ts-syntax-engine",
            architecture: "/node_modules/.bin/validation-architecture-engine"
        };
    }
    // ########################################
    Command.prototype.process = function () {
        var ciJsonPath = null;
        var status = '';
        this.consoleArguments.forEach(function (arg) {
            if (arg.includes('--ci-json-path')) {
                ciJsonPath = arg.split('=')[1];
            }
            if (arg.includes('--status-to-output')) {
                status = '--status-to-output';
            }
        });
        if (!ciJsonPath) {
            throw new Error('Set config: "--ci-json-path"');
        }
        if (!this.rulesetValidation.isValid(ciJsonPath)) {
            var outputError_1 = '';
            this.rulesetValidation.getErrorsMessages().forEach(function (error) {
                outputError_1 += error + '\n';
            });
            throw new Error(outputError_1);
        }
        this.projectRootPath = PATH.dirname(fs.realpathSync(ciJsonPath));
        var ciJsonBuffer = fs.readFileSync(ciJsonPath);
        var decodedJson = JSON.parse(ciJsonBuffer);
        var engineKeys = decodedJson['validation'];
        for (var engineKey in engineKeys) {
            var command = this.projectsBinPath[engineKey];
            var ruleset = engineKeys[engineKey];
            // TODO add for each of ruleset
            if (command && ruleset[0]) {
                var relativePathToCommand = PATH.join("" + this.projectRootPath, "" + command);
                var relativePathToRuleset = PATH.join("" + this.projectRootPath, "" + ruleset[0]);
                child_process_1.exec(relativePathToCommand + " run --ruleset=" + relativePathToRuleset + " " + status + " || exit 0", function (error, stdout, stderr) {
                    if (error) {
                        console.error("exec error: " + error);
                        return;
                    }
                    if (stdout) {
                        console.log(stdout);
                    }
                    if (stderr) {
                        throw new Error(stderr);
                    }
                });
            }
        }
    };
    return Command;
}());
exports.Command = Command;
